#
# spec file for package afl
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           afl
Version:        1.92b
Release:        3.5
Summary:        American fuzzy lop is a security-oriented fuzzer
License:        Apache-2.0
Group:          Development/Tools/Debuggers
Url:            http://lcamtuf.coredump.cx/afl/
Source:         http://lcamtuf.coredump.cx/afl/releases/%{name}-%{version}.tgz
Source1:        afl-rpmlintrc
Patch1:         afl-1.58b-fix-paths.patch
BuildRequires:  gcc-c++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  i586 x86_64

%description
American fuzzy lop is a security-oriented fuzzer that employs a novel type of compile-time instrumentation and genetic algorithms to automatically discover clean, interesting test cases that trigger new internal states in the targeted binary. This substantially improves the functional coverage for the fuzzed code. The compact synthesized corpora produced by the tool are also useful for seeding other, more labor- or resource-intensive testing regimes down the road.

Compared to other instrumented fuzzers, afl-fuzz is designed to be practical: it has modest performance overhead, uses a variety of highly effective fuzzing strategies and effort minimization tricks, requires essentially no configuration, and seamlessly handles complex, real-world use cases - say, common image parsing or file compression libraries.

%prep
%setup -q
%patch1 -p1

%build
export CFLAGS="$CFLAGS %{optflags}"
make PREFIX=%{_prefix} LIBEXEC_DIR=%{_libexecdir} DOC_DIR=%{_docdir} %{?_smp_mflags}

%install
make PREFIX=%{_prefix} LIBEXEC_DIR=%{_libexecdir} DOC_DIR=%{_docdir} DESTDIR=%{buildroot} install %{?_smp_mflags}

%files
%defattr(-,root,root)
%doc docs/COPYING
%{_bindir}/%{name}-*
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/%{name}-as
%{_libexecdir}/%{name}/as
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/testcases
%{_datadir}/%{name}/testcases/*

%changelog
* Mon Sep  7 2015 astieger@suse.com
- afl 1.92b:
  * C++ fix (namespaces)
* Thu Sep  3 2015 astieger@suse.com
- afl 1.91b:
  * C++ instrumentation fixes
- includes changes from 1.90b:
  * documentation updates
  * Fixed a potential problem with deferred mode signatures getting
    optimized out by the linker (with --gc-sections).
* Wed Sep  2 2015 astieger@suse.com
- afl 1.89b:
  * Revamped the support for persistent and deferred forkserver
    modes. Both now feature simpler syntax and do not require
    companion env variables.
  * Added a bit more info about afl-showmap.
* Sun Aug 30 2015 astieger@suse.com
- afl 1.88b:
  * Make AFL_EXIT_WHEN_DONE work in non-tty mode.
* Thu Aug 27 2015 astieger@suse.com
- afl 1.87b:
  * Add QuickStartGuide.txt and other documentation updates
* Mon Aug 10 2015 astieger@suse.com
- afl 1.86b:
  * Added support for AFL_SKIP_CRASHES
  * Removed the hard-fail terminal size check
* Wed Aug  5 2015 mpluskal@suse.com
- Update to 1.85b
  * Fixed a garbled sentence in notes on parallel fuzzing.
  * Fixed a minor glitch in afl-cmin.
- Changes for 1.84b
  * Made SIMPLE_FILES behave as expected when naming backup
    directories for crashes and hangs.
  * Added the total number of favored paths to fuzzer_stats.
  * Made afl-tmin, afl-fuzz, and afl-cmin reject negative values
    passed to -t and -m, since they generally won't work as
    expected.
  * Made a fix for no lahf / sahf support on older versions of
    FreeBSD.
* Mon Jun 15 2015 astieger@suse.com
- afl 1.83b:
  * fixes for platforms other than GNU/Linux
* Sat Jun 13 2015 astieger@suse.com
- afl 1.82b:
  * Fixed a harmless but annoying race condition in persistent mode
  * Updated persistent mode documentation
  - Tweaked AFL_PERSISTENT to force AFL_NO_VAR_CHECK.
- afl 1.81b:
  * Added persistent mode for in-process fuzzing.
  * in-place resume code to preserve crashes/README.txt.
* Tue May 26 2015 astieger@suse.com
- afl 1.80b:
  - Made afl-cmin tolerant of whitespaces in filenames
  - Added support for AFL_EXIT_WHEN_DONE
* Mon May 25 2015 astieger@suse.com
- afl 1.79b:
  - Added support for dictionary levels, see testcases/README.testcases.
  - Reworked the SQL dictionary to use levels.
  - Added a note about Preeny.
* Tue May 19 2015 astieger@suse.com
- builds for i586 x86_64 only
* Mon May 18 2015 astieger@suse.com
- afl 1.78b:
  - Added a dictionary for PDF
  - Added several references to afl-cov
* Fri May  8 2015 astieger@suse.com
- afl 1.77b:
  * additional fuzzing functionality
  * reduce number of duplicates
  * documentation updates
  * qemu_mode with qemu 2.3.0
* Mon Apr 27 2015 astieger@suse.com
- afl 1.73b:
  - Fixed a bug in effector maps that could sometimes cause more
    fuzzing than necessary, or SEGV
- includes changes from 1.72b:
  - Fixed a glitch in non-x86 install
  - Added a minor safeguard to llvm_mode Makefile
* Mon Apr 20 2015 astieger@suse.com
- afl 1.71b:
  - Fix bug with installed copies of AFL trying to use QEMU mode.
  - Add last path / crash / hang times to fuzzer_stats
- with changes from 1.70b:
  - Modify resumption code to reuse the original timeout value when
    resuming a session if -t is not given. This prevents timeout
    creep in continuous fuzzing.
  - Add improved error messages for failed handshake when
    AFL_DEFER_FORKSRV is set.
  - slight improvement to llvm_mode/Makefile
  - Refresh several bits of documentation.
* Thu Apr 16 2015 astieger@suse.com
- afl 1.69b:
  - Added support for deferred initialization in LLVM mode.
- afl 1.68b:
  - Fixed a minor PRNG glitch that would make the first seconds of
    a fuzzing job deterministic.
  - Made tmp[] static in the LLVM runtime to keep Valgrind happy
  - Clarified the footnote in README.
* Mon Apr 13 2015 astieger@suse.com
- afl 1.67b:
  - One more correction to llvm_mode Makefile
- afl 1.66b:
  - Added CC / CXX support to llvm_mode Makefile
  - Fixed 'make clean' with gmake
  - Fixed 'make -j n clean all'
  - Removed build date and time from banners to give people deterministic
    builds
  - drop afl-1.46b-nodate.patch, thus obsoleted
* Mon Apr 13 2015 astieger@suse.com
- afl 1.65b:
  - Fixed a snafu with some leftover code in afl-clang-fast.
  - Corrected even moar typos.
* Sun Apr 12 2015 astieger@suse.com
- afl 1.64b:
  - improve compatibility with non-ELF platforms.
  - Fixed a problem with afl-clang-fast and -shared libraries.
  - Removed unnecessary instrumentation density adjustment for LLVM
- includes changes from 1.63b:
  - Updated cgroups_asan/
  - Fixed typos
* Sat Apr 11 2015 astieger@suse.com
- afl 1.62b:
  - Improved the handling of -x in afl-clang-fast,
  - Improved the handling of low AFL_INST_RATIO settings for QEMU and
    LLVM modes.
  - Fixed the llvm-config bug for good
- includes changes from 1.61b:
  - Fixed an obscure bug compiling OpenSSL with afl-clang-fast.
  - Fixed a 'make install' bug on non-x86 systems
  - Fixed a problem with half-broken llvm-config
* Thu Apr  9 2015 astieger@suse.com
- afl 1.60b:
  * Allowed experimental/llvm_instrumentation/ to graduate to llvm_mode/.
  * Removed experimental/arm_support/, since it's completely broken and likely
    unnecessary with LLVM support in place.
  * Added ASAN cgroups script to experimental/asan_cgroups/, updated existing
    docs. Courtesy Sam Hakim and David A. Wheeler.
  * Refactored afl-tmin to reduce the number of execs in common use cases.
    Ideas from Jonathan Neuschafer and Turo Lamminen.
  * Added a note about CLAs at the bottom of README.
  * Renamed testcases_readme.txt to README.testcases for some semblance of
    consistency.
  * Made assorted updates to docs.
- includes changes from 1.59b
  * Imported Laszlo Szekeres' experimental LLVM instrumentation into
    experimental/llvm_instrumentation. I'll work on including it in the
    "mainstream" version soon.
- updates afl-1.46b-nodate.patch
* Fri Mar 27 2015 astieger@suse.com
- fix SLE 11 SP3 build, add afl-1.58b-fix-paths.patch
* Fri Mar 27 2015 astieger@suse.com
- afl 1.58b:
  * Added a workaround for abort() behavior in -lpthread programs in
    QEMU mode.
  * Made several documentation updates, including links to the
    static instrumentation tool (sister_projects.txt).
- use libexecdir
* Tue Mar 24 2015 meissner@suse.com
- updated to 1.57b
* Mon Feb 16 2015 astieger@suse.com
- initial package
